******ANALYSIS FILE****
cd "C:\Users\ddoherty\Documents\Colorado Republican Party\Paper\PRQ Final\REPLICATION"
clear all
set mem 500m

****USE MASTER DATA FILE
use "data_for_analysis.dta", clear

*** Pre Treatment Measures
label var voterscoregeneral "Turnout in Previous 4 General Elections (1-4)"
label var age "Age in 2012"
tab gender, gen(sex_)
rename sex_1 female
rename sex_2 male
label var female "Female (1=yes)"
label var male "Male (1=yes)"
label var sex_3 "Unknown Gender (1=yes)"

***RECODE OUTCOME MEASURES
rename lang_fe1 good_guy_eval
rename hudak_fe1 bad_guy_eval

recode good_guy_eval (1 2 4=1) (3=0) (*=.), gen(rec_good_guy)
recode bad_guy_eval (1 2 4=1) (3=0) (*=.), gen(rec_bad_guy)
recode good_guy_eval (1 2=1) (3 4=0) (*=.), gen(rec_good_guy_alt)
recode bad_guy_eval (1 2=1) (3 4=0) (*=.), gen(rec_bad_guy_alt)
label var rec_good_guy "Recognize Rep. (1=Yes; 0=No; Unsure=Yes)"
label var rec_bad_guy "Recognize Dem. (1=Yes; 0=No; Unsure=Yes)"
label var rec_good_guy_alt "Recognize Rep. (1=Yes; 0=No; Unsure=No)"
label var rec_bad_guy_alt "Recognize Dem. (1=Yes; 0=No; Unsure=No)"

recode good_guy_eval (1=1) (2=-1) (3 4=0) (*=.), gen(eval_good_guy)
recode bad_guy_eval (1=1) (2=-1) (3 4=0) (*=.), gen(eval_bad_guy)
recode good_guy_eval (1=1) (2=-1) (4=0) (*=.), gen(eval_good_guy_alt)
recode bad_guy_eval (1=1) (2=-1) (4=0) (*=.), gen(eval_bad_guy_alt)
label var eval_good_guy "Evaluate Rep. (1=Favorable; -1=Unfavorable; 0=DK or Never Heard Of)"
label var eval_bad_guy "Evaluate Dem. (1=Favorable; -1=Unfavorable; 0=DK or Never Heard Of)"
label var eval_good_guy_alt "Evaluate Rep. (1=Favorable; -1=Unfavorable; 0=DK; Never Heard Of=missing)"
label var eval_bad_guy_alt "Evaluate Dem. (1=Favorable; -1=Unfavorable; 0=DK; Never Heard Of=missing)"

gen eval_diff=eval_good_guy-eval_bad_guy 
gen eval_diff_alt=eval_good_guy_alt-eval_bad_guy_alt 

label var eval_diff "Difference in Evaluation (Rep-Dem; DK/Never Heard of 0s)"
label var eval_diff_alt "Difference in Evaluation (Rep-Dem; Restricted to those who Evaluated Both)"

recode mail_fe1 (1=1) (2 3=0), gen(def_rec_mail)
recode mail_fe1 (1=1) (3=0) (2=-1), gen(rec_mail)
label var def_rec_mail "Yes, Received mail (1=yes)"
label var rec_mail "Received mail (1=yes; 0=unsure;-1=no)"

recode registered_fe1 (1 3=1) (2=0), gen(registered_tovote)
label var registered_tovote "Registered or Unsure if Reg. (1=yes)"

recode liklihood_fe1 (1=4) (2=3) (3=2) (4=1) (*=.), gen(intend_vote)
label var intend_vote "Intent to Vote (1=Definitely not; 4=Definitely will)"


*** TREATMENT INDICATORS
tab treat, gen(treat_)
drop treat_1
rename treat_2 treat_pos
rename treat_3 treat_neg
label var treat_pos "Positive Mailer Treatment"
label var treat_neg "Negative Mailer Treatment"

*** OTHER MEASURES
tab strata, gen(strat_)
drop strat_1
rename strat_2 strat_1ph_multhh
rename strat_3 strat_multph_multhh
label var strat_1ph_multhh "Strata (1 phone; multi-voter HH)"
label var strat_multph_multhh "Strata (shared phone; multi-voter HH)"

tab sdname, gen(dist_)
drop dist_1
rename dist_2 dist_26
rename dist_3 dist_35
label var dist_26 "District 26 (1=yes)"
label var dist_35 "District 35 (1=yes)"

***** RESPONSE RATES/PATTERNS
foreach i in dist_26 strat_1ph_multhh strat_multph_multhh female male age{
gen `i'Xpos=`i'*treat_pos
gen `i'Xneg=`i'*treat_neg
local label : variable label `i'
label var `i'Xpos "Positive Treatment x `label'"
label var `i'Xneg "Negative Treatment x `label'"
}

reg contact treat_pos treat_neg 
reg contact treat_* dist_26 strat_1ph_multhh strat_multph_multhh female male age *Xneg *Xpos
test dist_26Xpos dist_26Xneg strat_1ph_multhhXpos strat_1ph_multhhXneg strat_multph_multhhXpos strat_multph_multhhXneg femaleXpos femaleXneg maleXpos maleXneg ageXpos ageXneg
drop *Xpos *Xneg

*** SAMPLE RESTRICTION. 
reg rec_good_guy rec_bad_guy rec_mail registered_tovote intend_vote if contact==1
gen full_complete_first=e(sample)

** treat associated with "not registered" - NO.
reg registered_tovote treat_neg treat_pos, r
* exclude individuals who report not being registered
replace full_complete_first=0 if registered_tovote==0

**** BALANCE
mlogit treat  voterscoregeneral dist_26 female male age if full_complete_first==1, r 


***************************************************
********REGRESSION MODELS (TABLE 1)****************
***************************************************
foreach i in def_rec_mail rec_good_guy rec_bad_guy eval_good_guy eval_bad_guy eval_diff intend_vote {
reg `i' treat_pos treat_neg if full_complete_first==1, r 
qui test treat_pos
local p_pos=r(p)
qui test treat_neg
local p_neg=r(p)
test treat_pos==treat_neg
local p_diff=r(p)
test treat_pos treat_neg
if "`i'"=="def_rec_mail"{
outreg2 using "field_exp_core.out", se bracket replace excel dec(3) label alpha(0.01, .05, 0.10) addstat(Positive Mailer p-value, `p_pos',Negative Mailer p-value, `p_neg',p-value of Difference Between Treatments, `p_diff', p-value of Joint Significance of Treatments, r(p))
}
else{
outreg2 using "field_exp_core.out", se bracket append excel dec(3) label alpha(0.01, .05, 0.10) addstat(Positive Mailer p-value, `p_pos',Negative Mailer p-value, `p_neg',p-value of Difference Between Treatments, `p_diff', p-value of Joint Significance of Treatments, r(p))
}

************************************
**** TABLE 1 w/controls (TABLE S3)**
************************************
reg `i' treat_pos treat_neg strat_* voterscoregeneral dist_26 female male age if full_complete_first==1, r 
qui test treat_pos
local p_pos=r(p)
qui test treat_neg
local p_neg=r(p)
test treat_pos==treat_neg
local p_diff=r(p)
test treat_pos treat_neg
if "`i'"=="def_rec_mail"{
outreg2 using "field_exp_core_ctrls.out", se bracket replace excel dec(3) label alpha(0.01, .05, 0.10) addstat(Positive Mailer p-value, `p_pos',Negative Mailer p-value, `p_neg',p-value of Difference Between Treatments, `p_diff', p-value of Joint Significance of Treatments, r(p))
}
else{
outreg2 using "field_exp_core_ctrls.out", se bracket append excel dec(3) label alpha(0.01, .05, 0.10) addstat(Positive Mailer p-value, `p_pos',Negative Mailer p-value, `p_neg',p-value of Difference Between Treatments, `p_diff', p-value of Joint Significance of Treatments, r(p))
}
}
*****************************************************
******** ALTERNATE OUTCOME MEASURES (TABLE S4) ******
*****************************************************
foreach i in rec_mail rec_good_guy_alt rec_bad_guy_alt {
reg `i' treat_pos treat_neg if full_complete_first==1, r 
qui test treat_pos
local p_pos=r(p)
qui test treat_neg
local p_neg=r(p)
test treat_pos==treat_neg
local p_diff=r(p)
test treat_pos treat_neg
if "`i'"=="rec_mail"{
outreg2 using "field_exp_alt.out", se bracket replace excel dec(3) label alpha(0.01, .05, 0.10) addstat(Positive Mailer p-value, `p_pos',Negative Mailer p-value, `p_neg',p-value of Difference Between Treatments, `p_diff', p-value of Joint Significance of Treatments, r(p))
}
else{
outreg2 using "field_exp_alt.out", se bracket append excel dec(3) label alpha(0.01, .05, 0.10) addstat(Positive Mailer p-value, `p_pos',Negative Mailer p-value, `p_neg',p-value of Difference Between Treatments, `p_diff', p-value of Joint Significance of Treatments, r(p))
}
}
************************************************************
******** HETEROGENEITY OF TREATMENT EFFECTS (TABLE S1) *****
************************************************************
foreach i in dist_26 strat_1ph_multhh strat_multph_multhh {
gen `i'Xpos=`i'*treat_pos
gen `i'Xneg=`i'*treat_neg
local label : variable label `i'
label var `i'Xpos "Positive Treatment x `label'"
label var `i'Xneg "Negative Treatment x `label'"
}
foreach i in def_rec_mail rec_good_guy rec_bad_guy eval_good_guy eval_bad_guy eval_diff intend_vote {
reg `i' treat_pos treat_neg strat_1ph_multhh strat_multph_multhh dist_26 strat*X* dist_26X* if full_complete_first==1, r 
qui test strat_1ph_multhhXneg strat_1ph_multhhXpos strat_multph_multhhXneg strat_multph_multhhXpos
local stratX=r(p)
qui test dist_26Xpos dist_26Xneg
if "`i'"=="def_rec_mail"{
outreg2 using "strata_dist_X.out", se bracket replace excel dec(3) label alpha(0.01, .05, 0.10) addstat(Strata Interactions (p-value), `stratX',District Interactions (p-value), r(p))
}
else{
outreg2 using "strata_dist_X.out", se bracket append excel dec(3) label alpha(0.01, .05, 0.10) addstat(Strata Interactions (p-value), `stratX',District Interactions (p-value), r(p))
}
}



*****************************
** SECOND FIELD EXPERIMENT **
*****************************
***RECODE OUTCOME MEASURES
drop good_guy_eval-liklihood_fe1 rec_good_guy-intend_vote *X*
rename lang good_guy_eval
rename hudak bad_guy_eval

recode good_guy_eval (1 2 4=1) (3=0) (*=.), gen(rec_good_guy)
recode bad_guy_eval (1 2 4=1) (3=0) (*=.), gen(rec_bad_guy)
recode good_guy_eval (1 2=1) (3 4=0) (*=.), gen(rec_good_guy_alt)
recode bad_guy_eval (1 2=1) (3 4=0) (*=.), gen(rec_bad_guy_alt)
label var rec_good_guy "Recognize Rep. (1=Yes; 0=No; Unsure=Yes)"
label var rec_bad_guy "Recognize Dem. (1=Yes; 0=No; Unsure=Yes)"
label var rec_good_guy_alt "Recognize Rep. (1=Yes; 0=No; Unsure=No)"
label var rec_bad_guy_alt "Recognize Dem. (1=Yes; 0=No; Unsure=No)"

recode good_guy_eval (1=1) (2=-1) (3 4=0) (*=.), gen(eval_good_guy)
recode bad_guy_eval (1=1) (2=-1) (3 4=0) (*=.), gen(eval_bad_guy)
recode good_guy_eval (1=1) (2=-1) (4=0) (*=.), gen(eval_good_guy_alt)
recode bad_guy_eval (1=1) (2=-1) (4=0) (*=.), gen(eval_bad_guy_alt)
label var eval_good_guy "Evaluate Rep. (1=Favorable; -1=Unfavorable; 0=DK or Never Heard Of)"
label var eval_bad_guy "Evaluate Dem. (1=Favorable; -1=Unfavorable; 0=DK or Never Heard Of)"
label var eval_good_guy_alt "Evaluate Rep. (1=Favorable; -1=Unfavorable; 0=DK; Never Heard Of=missing)"
label var eval_bad_guy_alt "Evaluate Dem. (1=Favorable; -1=Unfavorable; 0=DK; Never Heard Of=missing)"

gen eval_diff=eval_good_guy-eval_bad_guy 
gen eval_diff_alt=eval_good_guy_alt-eval_bad_guy_alt 

label var eval_diff "Difference in Evaluation (Rep-Dem; DK/Never Heard of 0s)"
label var eval_diff_alt "Difference in Evaluation (Rep-Dem; Restricted to those who Evaluated Both)"

recode mail (1=1) (2 3=0), gen(def_rec_mail)
recode mail (1=1) (3=0) (2=-1), gen(rec_mail)
label var def_rec_mail "Yes, Received mail (1=yes)"
label var rec_mail "Received mail (1=yes; 0=unsure;-1=no)"

recode registered (1 3=1) (2=0), gen(registered_tovote)
label var registered_tovote "Registered or Unsure if Reg. (1=yes)"

recode liklihood (1=4) (2=3) (3=2) (4=1) (*=.), gen(intend_vote)
label var intend_vote "Intent to Vote (1=Definitely not; 4=Definitely will)"

*** TREATMENT INDICATORS
rename treat_pos first_treat_pos
rename treat_neg first_treat_neg
replace first_treat_pos=0 if first_treat_pos==.
replace first_treat_neg=0 if first_treat_neg==.
label var first_treat_pos "Positive Mailer Treatment (1st round)"
label var first_treat_neg "Negative Mailer Treatment (1st round)"

tab treat_new, gen(treat_)
drop treat_1
rename treat_2 treat_pos
rename treat_3 treat_neg
rename treat_4 treat_con
label var treat_pos "Positive Mailer Treatment"
label var treat_neg "Negative Mailer Treatment"
label var treat_con "Contrast Mailer Treatment"

*Interactions between 1st and 2nd treatments*
foreach i in treat_pos treat_neg treat_con{
local label : variable label `i'
gen `i'Xfirst_neg=`i'*first_treat_neg
label var `i'Xfirst_neg "`label' x Negative (1st Round)"
gen `i'Xfirst_pos=`i'*first_treat_pos
label var `i'Xfirst_pos "`label' x Positive (1st Round)"
}

*** drop cases not in sample
drop if treat_new==.
*drop .03% of cases where no record of voting in past 4 GEs
drop if voterscoregeneral==0

***** RESPONSE RATES/PATTERNS
foreach i in dist_26 dist_35 strat_1ph_multhh strat_multph_multhh female male age{
gen `i'Xpos=`i'*treat_pos
gen `i'Xneg=`i'*treat_neg
gen `i'Xcon=`i'*treat_con
local label : variable label `i'
label var `i'Xpos "Positive Treatment x `label'"
label var `i'Xneg "Negative Treatment x `label'"
label var `i'Xcon "Contrast Treatment x `label'"
}

reg contact_2 treat_pos treat_neg treat_con
reg contact_2 treat_pos treat_neg treat_con dist_26 strat_1ph_multhh strat_multph_multhh female male age *Xneg *Xpos *Xcon
test dist_26Xpos dist_26Xneg dist_26Xcon dist_35Xpos dist_35Xneg dist_35Xcon strat_1ph_multhhXpos strat_1ph_multhhXneg strat_1ph_multhhXcon strat_multph_multhhXpos strat_multph_multhhXneg strat_multph_multhhXcon femaleXpos femaleXneg femaleXcon maleXpos maleXneg maleXcon ageXpos ageXneg ageXcon
drop *Xpos *Xneg *Xcon


*** SAMPLE RESTRICTION. 
reg rec_good_guy rec_bad_guy rec_mail registered_tovote intend_vote if contact_2==1
gen full_complete=e(sample)

** treat associated with "not registered" - NO.
reg registered_tovote treat_neg treat_pos treat_con, r
* exclude individuals who report not being registered
replace full_complete=0 if registered_tovote==0

*** Summary Stats by District
outsum strat_* voterscoregeneral female male age first_treat_* treat_pos treat_neg treat_con if sdname==19 using "summary", replace bracket ctitle(District 19)
outsum strat_* voterscoregeneral female male age first_treat_* treat_pos treat_neg treat_con if sdname==26 using "summary", append bracket ctitle(District 26)
outsum strat_* voterscoregeneral female male age first_treat_* treat_pos treat_neg treat_con if sdname==35 using "summary", append bracket ctitle(District 35)

outsum strat_* voterscoregeneral female male age first_treat_* treat_pos treat_neg treat_con dist_* def_rec_mail rec_good_guy rec_bad_guy eval_good_guy eval_bad_guy eval_diff intend_vote if full_complete_first==1 using "summary", append bracket ctitle(First Field Experiment)
outsum strat_* voterscoregeneral female male age first_treat_* treat_pos treat_neg treat_con dist_* def_rec_mail rec_good_guy rec_bad_guy eval_good_guy eval_bad_guy eval_diff intend_vote if full_complete==1 using "summary", append  bracket ctitle(Second Field Experiment)

**** BALANCE
mlogit treat_new voterscoregeneral dist_26 dist_35 female male age if full_complete==1, r 


******************************************
********REGRESSION MODELS (TABLE 2) ******
******************************************
foreach i in def_rec_mail rec_good_guy rec_bad_guy eval_good_guy eval_bad_guy eval_diff intend_vote {
reg `i' treat_pos treat_neg treat_con first_treat_* dist_35 if full_complete==1, r 
qui test treat_pos treat_neg treat_con
local p_treat=r(p)
qui test first_treat_pos first_treat_neg
local p_first=r(p)
if "`i'"=="def_rec_mail"{
outreg2 using "sec_field_exp_core.out", se bracket replace excel dec(3) label alpha(0.01, .05, 0.10) addstat(p-value of Second Round Treatments, `p_treat',p-value of First Round Treatments, `p_first')
}
else{
outreg2 using "sec_field_exp_core.out", se bracket append excel dec(3) label alpha(0.01, .05, 0.10) addstat(p-value of Second Round Treatments, `p_treat',p-value of First Round Treatments, `p_first')
}
************************************
**** TABLE 2 w/controls (TABLE S6)**
************************************
reg `i' treat_pos treat_neg treat_con first_treat_* strat_* voterscoregeneral dist_26 dist_35 female male age if full_complete==1, r 
qui test treat_pos treat_neg treat_con
local p_treat=r(p)
qui test first_treat_pos first_treat_neg
local p_first=r(p)
if "`i'"=="def_rec_mail"{
outreg2 using "sec_field_exp_core_ctrls.out", se bracket replace excel dec(3) label alpha(0.01, .05, 0.10) addstat(p-value of Second Round Treatments, `p_treat',p-value of First Round Treatments, `p_first')
}
else{
outreg2 using "sec_field_exp_core_ctrls.out", se bracket append excel dec(3) label alpha(0.01, .05, 0.10) addstat(p-value of Second Round Treatments, `p_treat',p-value of First Round Treatments, `p_first')
}
*w/treatment interactions (FN 13)
reg `i' treat_pos treat_neg treat_con first_treat_* treat*X* strat_* if full_complete==1, r 
qui test treat_posXfirst_neg treat_posXfirst_pos treat_negXfirst_neg treat_negXfirst_pos treat_conXfirst_neg treat_conXfirst_pos
if "`i'"=="def_rec_mail"{
outreg2 using "sec_field_exp_treatX.out", se bracket replace excel dec(3) label alpha(0.01, .05, 0.10) addstat(p-value of Treatment Interactions, r(p))
}
else{
outreg2 using "sec_field_exp_treatX.out", se bracket append excel dec(3) label alpha(0.01, .05, 0.10) addstat(p-value of Treatment Interactions, r(p))
}
}
*****************************************************
******** ALTERNATE OUTCOME MEASURES (TABLE S7) ******
*****************************************************
foreach i in rec_mail rec_good_guy_alt rec_bad_guy_alt {
reg `i' treat_pos treat_neg treat_con first_treat_* dist_35 if full_complete==1, r 
qui test treat_pos treat_neg treat_con
local p_treat=r(p)
qui test first_treat_pos first_treat_neg
local p_first=r(p)
test treat_pos treat_neg treat_con first_treat_pos first_treat_neg
if "`i'"=="rec_mail"{
outreg2 using "sec_field_exp_alt.out", se bracket replace excel dec(3) label alpha(0.01, .05, 0.10) addstat(p-value of Second Round Treatments, `p_treat',p-value of First Round Treatments, `p_first', p-value of Joint Significance of All Treatments, r(p))
}
else{
outreg2 using "sec_field_exp_alt.out", se bracket append excel dec(3) label alpha(0.01, .05, 0.10) addstat(p-value of Second Round Treatments, `p_treat',p-value of First Round Treatments, `p_first', p-value of Joint Significance of All Treatments, r(p))
}
}


************************************************************
******** HETEROGENEITY OF TREATMENT EFFECTS (TABLE S5) *****
************************************************************
foreach i in dist_26 dist_35 strat_1ph_multhh strat_multph_multhh {
gen `i'Xpos=`i'*treat_pos
gen `i'Xneg=`i'*treat_neg
gen `i'Xcon=`i'*treat_con
gen `i'Xfirst_pos=`i'*first_treat_pos
gen `i'Xfirst_neg=`i'*first_treat_neg
local label : variable label `i'
label var `i'Xpos "Positive Treatment x `label'"
label var `i'Xneg "Negative Treatment x `label'"
label var `i'Xcon "Contrast Treatment x `label'"
label var `i'Xfirst_pos "First Exp. Positive Treatment x `label'"
label var `i'Xfirst_neg "First Exp. Negative Treatment x `label'"
}
foreach i in def_rec_mail rec_good_guy rec_bad_guy eval_good_guy eval_bad_guy eval_diff intend_vote {
reg `i' treat_pos treat_neg treat_con first_treat_* strat_1ph_multhh strat_multph_multhh dist_26 dist_35 strat*X* dist_26X* dist_35X* if full_complete==1, r 
qui test strat_1ph_multhhXneg strat_1ph_multhhXpos strat_1ph_multhhXcon strat_multph_multhhXneg strat_multph_multhhXpos strat_multph_multhhXcon
local stratX=r(p)
qui test strat_1ph_multhhXfirst_neg strat_1ph_multhhXfirst_pos strat_multph_multhhXfirst_neg strat_multph_multhhXfirst_pos 
local stratXfirst=r(p)
qui test dist_26Xpos dist_26Xneg dist_26Xcon dist_35Xpos dist_35Xneg dist_35Xcon
local districtX=r(p)
qui test dist_26Xfirst_pos dist_26Xfirst_neg 
local districtXfirst=r(p)

if "`i'"=="def_rec_mail"{
outreg2 using "sec_strata_dist_X.out", se bracket replace excel dec(3) label alpha(0.01, .05, 0.10) addstat(Strata Interactions (p-value), `stratX',Strata Interactions (first round treatments; p-value), `stratXfirst',District Interactions (p-value), `districtX', District Interactions (first round treatments; p-value),`districtXfirst')
}
else{
outreg2 using "sec_strata_dist_X.out", se bracket append excel dec(3) label alpha(0.01, .05, 0.10) addstat(Strata Interactions (p-value), `stratX',Strata Interactions (first round treatments; p-value), `stratXfirst',District Interactions (p-value), `districtX', District Interactions (first round treatments; p-value),`districtXfirst')
}
}

*******************************************
******** VALIDATED TURNOUT (TABLE S8) *****
*******************************************
gen voted_alt=voted
replace voted_alt=0 if voted==.
label var voted "Voted in 2012 (1=yes; missing=missing)"
label var voted_alt "Voted in 2012 (1=yes; missing=0)"

foreach s in "full_complete<2" "full_complete==1"{
foreach i in voted voted_alt{
reg `i' treat_pos treat_neg treat_con first_treat_pos first_treat_neg dist_35 if `s', r
qui test treat_pos treat_neg treat_con
local p_treat=r(p)
qui test first_treat_pos first_treat_neg
local p_first=r(p)
qui test treat_pos treat_neg treat_con first_treat_pos first_treat_neg
if "`i'"=="voted" & "`s'"=="full_complete<2"{
outreg2 using "validated_analysis.out", se bracket replace excel dec(3) label alpha(0.01, .05, 0.10) addstat(p-value of Second Round Treatments, `p_treat',p-value of First Round Treatments, `p_first', p-value of Joint Significance of All Treatments, r(p))
}
else{
outreg2 using "validated_analysis.out", se bracket append excel dec(3) label alpha(0.01, .05, 0.10) addstat(p-value of Second Round Treatments, `p_treat',p-value of First Round Treatments, `p_first', p-value of Joint Significance of All Treatments, r(p))
}
}
}


foreach i in voted voted_alt{
tab `i' intend_vote, col
}


