clear all
set mem 500m
cd "C:\Users\ddoherty\Documents\Colorado Republican Party\Paper\PRQ Final\REPLICATION"

**************************
****CLEAN SD 19 FILE *****
**************************
use "data_private\sd19.dta", clear
count
*DROP IF SAME NAME/SAME PHONE NUMBER LISTED MULTIPLE TIMES and then if SAME NAME/SAME ADDRESS MORE THAN ONCE
egen indiv_phone_id=group(lastname firstname middlename primaryphone), missing
egen indiv_phone_size=count(indiv_phone_id), by(indiv_phone_id)
drop if indiv_phone_size>1

egen indiv_hh_id=group(lastname firstname middlename primaryhousenumber primarystreetname primaryunitnumb primaryzip), missing
egen indiv_hh_size=count(indiv_hh_id), by(indiv_hh_id)
drop if indiv_hh_size>1

*ID UNIQUE HHs
egen hh_id=group(primaryhousenumber primarystreetname primaryunitnumb primaryzip), missing
egen hh_size=count(hh_id), by(hh_id)
drop if hh_size>4

*ID UNIQUE HH PHONE #s
egen phone_id=group(hh_id primaryphone), missing
egen phone_size=count(phone_id), by(phone_id)

** CREATE INDICATORS TO COUNT NON-MISSINGS OF FOR HH LEVEL MEASURES
tab partycode, gen(pty_)
forvalues i=1/6{
replace pty_`i'=. if pty_`i'==0
}
rename pty_1 pty_D
rename pty_2 pty_G
rename pty_3 pty_O
rename pty_4 pty_R
rename pty_5 pty_T
rename pty_6 pty_U

recode voterscoregeneral (0 5=0) (1=1) (2=2) (3=3) (4=4) (*=.), gen(generals)

tab generals, gen(gen_)
forvalues i=1/5{
local newindex=`i'-1
rename gen_`i' gen_`newindex'
replace gen_`newindex'=. if gen_`newindex'!=1
}

*** GENERATE MEASURES OF HH CHARACTERISTICS FOR EACH VOTER
foreach u in hh_id phone_id{
foreach p in D R U G T O{
egen no_`p'_`u'=count(pty_`p'), by(`u')
}
forvalues i=0/4{
egen no_gentimes_`i'_`u'=count(gen_`i'), by(`u')
}
}

*DROP BAD/MISSING PHONE NUMBERS
drop if primaryphone==.
drop if primaryphone<2000000000
tostring primaryphone, generate(phone_string)
gen first_dig_prefix=substr(phone_string,4,1)
*drop if first digit of prefix < 2
drop if first_dig_prefix=="1" | first_dig_prefix=="0" 

*** GENERATE COUNTS OF NUMBER OF PEOPLE SHARING A PHONE NUMBER
egen shared_phone_id=group(primaryphone), missing
egen shared_phone_size=count(shared_phone_id), by(shared_phone_id)
gsort primaryphone hh_id 

* DROP IMPLAUSIBLY SHARED PHONE NUMBERS
gsort primaryphone hh_id 
count if (primaryphone[_n+1]==primaryphone & hh_id[_n+1]!=hh_id) |(primaryphone[_n-1]==primaryphone & hh_id[_n-1]!=hh_id)| (primaryphone[_n+2]==primaryphone & hh_id[_n+2]!=hh_id) |(primaryphone[_n-2]==primaryphone & hh_id[_n-2]!=hh_id) | (primaryphone[_n+3]==primaryphone & hh_id[_n+3]!=hh_id) |(primaryphone[_n-3]==primaryphone & hh_id[_n-3]!=hh_id) |(primaryphone[_n+4]==primaryphone & hh_id[_n+4]!=hh_id) |(primaryphone[_n-4]==primaryphone & hh_id[_n-4]!=hh_id) 
count if (primaryphone[_n+1]==primaryphone & lastname[_n+1]==lastname & hh_id[_n+1]!=hh_id)|(primaryphone[_n-1]==primaryphone & lastname[_n-1]==lastname & hh_id[_n-1]!=hh_id)| (primaryphone[_n+2]==primaryphone & lastname[_n+2]==lastname & hh_id[_n+2]!=hh_id)|(primaryphone[_n-2]==primaryphone & lastname[_n-2]==lastname & hh_id[_n-2]!=hh_id)| (primaryphone[_n+3]==primaryphone & lastname[_n+3]==lastname & hh_id[_n+3]!=hh_id)|(primaryphone[_n-3]==primaryphone & lastname[_n-3]==lastname & hh_id[_n-3]!=hh_id)|(primaryphone[_n+4]==primaryphone & lastname[_n+4]==lastname & hh_id[_n+4]!=hh_id)|(primaryphone[_n-4]==primaryphone & lastname[_n-4]==lastname & hh_id[_n-4]!=hh_id) 
drop if (primaryphone[_n+1]==primaryphone & hh_id[_n+1]!=hh_id) |(primaryphone[_n-1]==primaryphone & hh_id[_n-1]!=hh_id)| (primaryphone[_n+2]==primaryphone & hh_id[_n+2]!=hh_id) |(primaryphone[_n-2]==primaryphone & hh_id[_n-2]!=hh_id) | (primaryphone[_n+3]==primaryphone & hh_id[_n+3]!=hh_id) |(primaryphone[_n-3]==primaryphone & hh_id[_n-3]!=hh_id) |(primaryphone[_n+4]==primaryphone & hh_id[_n+4]!=hh_id) |(primaryphone[_n-4]==primaryphone & hh_id[_n-4]!=hh_id) 

** DROP non-Targeted individuals
drop if var1!=1

*** DROP IF MORE THAN 2 PEOPLE SHARING PHONE NUMBER
drop if phone_size>2
egen target_hh_id=group(hh_id), missing

**** GENERATE STRATA (1=1-person HH, 1 phone; 2=multiperson HH, 1 phone; 3=multiperson HH, shared phone)
generate strata=3
replace strata=2 if phone_size==1 & hh_size!=1
replace strata=1 if phone_size==1 & hh_size==1
label var strata "1=1-person HH, 1 phone; 2=multiperson HH, 1 phone; 3=multiperson HH, shared phone"

*** DUMP OUT FULL POTENTIAL SAMPLE
save "data_private\sd19_full_ind.dta", replace

*** ASSIGN TREATMENT
gen treat=1
set seed 5099
gen withinHH=runiform()
set seed 552
gen treatassign=runiform()
gsort hh_id withinHH
drop if hh_id==hh_id[_n-1]
forvalues i=1/3{
_pctile treatassign if strata==`i', p(33.333, 66.667)
replace treat=0 if strata==`i' & treatassign<r(r1)
replace treat=2 if strata==`i' & treatassign>r(r2)
}
label var treat "Treatment Condition (0=control; 1=positive; 2=negative)"

*** YOB
gen yob=subinstr(dob,"1/1/","",.)
destring yob, replace
gen age=2012-yob
label var age "Age in 2012"

** gender
tab gender, gen(sex_)

*** OUTPUT DATA FOR CALLS
format primaryphone precinctnumber precinctname voterkey hhrecid clientid statevoterid %15.0g
set seed 1
gen callorder=runiform()
gsort callorder
outsheet using "data_private\call_list_sd19.csv", comma replace

**************************
****CLEAN SD 26 FILE *****
**************************
use "data_private\sd26.dta", clear
count
*DROP IF SAME NAME/SAME YOB and then SAME NAME/SAME PHONE NUMBER LISTED MULTIPLE TIMES and then if SAME NAME/SAME ADDRESS MORE THAN ONCE
egen indiv_phone_id=group(lastname firstname middlename primaryphone), missing
egen indiv_phone_size=count(indiv_phone_id), by(indiv_phone_id)
drop if indiv_phone_size>1

egen indiv_hh_id=group(lastname firstname middlename primaryhousenumber primarystreetname primaryunitnumb primaryzip), missing
egen indiv_hh_size=count(indiv_hh_id), by(indiv_hh_id)
drop if indiv_hh_size>1

*ID UNIQUE HHs
egen hh_id=group(primaryhousenumber primarystreetname primaryunitnumb primaryzip), missing
egen hh_size=count(hh_id), by(hh_id)
drop if hh_size>4

*ID UNIQUE HH PHONE #s
egen phone_id=group(hh_id primaryphone), missing
egen phone_size=count(phone_id), by(phone_id)


** CREATE INDICATORS TO COUNT NON-MISSINGS OF FOR HH LEVEL MEASURES
tab partycode, gen(pty_)
forvalues i=1/6{
replace pty_`i'=. if pty_`i'==0
}
rename pty_1 pty_D
rename pty_2 pty_G
rename pty_3 pty_O
rename pty_4 pty_R
rename pty_5 pty_T
rename pty_6 pty_U

recode voterscoregeneral (0 5=0) (1=1) (2=2) (3=3) (4=4) (*=.), gen(generals)
tab generals, gen(gen_)
forvalues i=1/5{
local newindex=`i'-1
rename gen_`i' gen_`newindex'
replace gen_`newindex'=. if gen_`newindex'!=1
}

*** GENERATE MEASURES OF HH CHARACTERISTICS FOR EACH VOTER
foreach u in hh_id phone_id{
foreach p in D R U G T O{
egen no_`p'_`u'=count(pty_`p'), by(`u')
}
forvalues i=0/4{
egen no_gentimes_`i'_`u'=count(gen_`i'), by(`u')
}
}

*DROP BAD/MISSING PHONE NUMBERS
drop if primaryphone==.
drop if primaryphone<2000000000
tostring primaryphone, generate(phone_string)
gen first_dig_prefix=substr(phone_string,4,1)
*drop if first digit of prefix < 2
drop if first_dig_prefix=="1" | first_dig_prefix=="0" 

*** GENERATE COUNTS OF NUMBER OF PEOPLE SHARING A PHONE NUMBER
egen shared_phone_id=group(primaryphone), missing
egen shared_phone_size=count(shared_phone_id), by(shared_phone_id)
gsort primaryphone hh_id 

* DROP IMPLAUSIBLY SHARED PHONE NUMBERS
gsort primaryphone hh_id 
count if (primaryphone[_n+1]==primaryphone & hh_id[_n+1]!=hh_id) |(primaryphone[_n-1]==primaryphone & hh_id[_n-1]!=hh_id)| (primaryphone[_n+2]==primaryphone & hh_id[_n+2]!=hh_id) |(primaryphone[_n-2]==primaryphone & hh_id[_n-2]!=hh_id) | (primaryphone[_n+3]==primaryphone & hh_id[_n+3]!=hh_id) |(primaryphone[_n-3]==primaryphone & hh_id[_n-3]!=hh_id) |(primaryphone[_n+4]==primaryphone & hh_id[_n+4]!=hh_id) |(primaryphone[_n-4]==primaryphone & hh_id[_n-4]!=hh_id) 
count if (primaryphone[_n+1]==primaryphone & lastname[_n+1]==lastname & hh_id[_n+1]!=hh_id)|(primaryphone[_n-1]==primaryphone & lastname[_n-1]==lastname & hh_id[_n-1]!=hh_id)| (primaryphone[_n+2]==primaryphone & lastname[_n+2]==lastname & hh_id[_n+2]!=hh_id)|(primaryphone[_n-2]==primaryphone & lastname[_n-2]==lastname & hh_id[_n-2]!=hh_id)| (primaryphone[_n+3]==primaryphone & lastname[_n+3]==lastname & hh_id[_n+3]!=hh_id)|(primaryphone[_n-3]==primaryphone & lastname[_n-3]==lastname & hh_id[_n-3]!=hh_id)|(primaryphone[_n+4]==primaryphone & lastname[_n+4]==lastname & hh_id[_n+4]!=hh_id)|(primaryphone[_n-4]==primaryphone & lastname[_n-4]==lastname & hh_id[_n-4]!=hh_id) 
drop if (primaryphone[_n+1]==primaryphone & hh_id[_n+1]!=hh_id) |(primaryphone[_n-1]==primaryphone & hh_id[_n-1]!=hh_id)| (primaryphone[_n+2]==primaryphone & hh_id[_n+2]!=hh_id) |(primaryphone[_n-2]==primaryphone & hh_id[_n-2]!=hh_id) | (primaryphone[_n+3]==primaryphone & hh_id[_n+3]!=hh_id) |(primaryphone[_n-3]==primaryphone & hh_id[_n-3]!=hh_id) |(primaryphone[_n+4]==primaryphone & hh_id[_n+4]!=hh_id) |(primaryphone[_n-4]==primaryphone & hh_id[_n-4]!=hh_id) 

** DROP non-Targeted individuals
drop if var1!=1

*** DROP IF MORE THAN 2 PEOPLE SHARING PHONE NUMBER
drop if phone_size>2
egen target_hh_id=group(hh_id), missing

**** GENERATE STRATA (1=1-person HH, 1 phone; 2=multiperson HH, 1 phone; 3=multiperson HH, shared phone)
generate strata=3
replace strata=2 if phone_size==1 & hh_size!=1
replace strata=1 if phone_size==1 & hh_size==1
label var strata "1=1-person HH, 1 phone; 2=multiperson HH, 1 phone; 3=multiperson HH, shared phone"

*** ASSIGN TREATMENT
gen treat=1
set seed 500
gen withinHH=runiform()
set seed 501
gen treatassign=runiform()
gsort hh_id withinHH
drop if hh_id==hh_id[_n-1]
forvalues i=1/3{
_pctile treatassign if strata==`i', p(33.333, 66.667)
replace treat=0 if strata==`i' & treatassign<r(r1)
replace treat=2 if strata==`i' & treatassign>r(r2)
}

*** YOB
gen yob=subinstr(dob,"1/1/","",.)
destring yob, replace
gen age=2012-yob
label var age "Age in 2012"

** gender
tab gender, gen(sex_)

*** OUTPUT CALL FILES 
format primaryphone precinctnumber precinctname voterkey hhrecid clientid statevoterid %15.0g
set seed 1
gen callorder=runiform()
gsort callorder
outsheet using "data_private\call_list_sd26.csv", comma replace

**************************
****CLEAN SD 35 FILE *****
**************************
clear all
use "data_private\sd35.dta", clear
count
*DROP IF SAME NAME/SAME PHONE NUMBER LISTED MULTIPLE TIMES and then if SAME NAME/SAME ADDRESS MORE THAN ONCE
egen indiv_phone_id=group(lastname firstname middlename primaryphone), missing
egen indiv_phone_size=count(indiv_phone_id), by(indiv_phone_id)
drop if indiv_phone_size>1

egen indiv_hh_id=group(lastname firstname middlename primaryhousenumber primarystreetname primaryunitnumb primaryzip), missing
egen indiv_hh_size=count(indiv_hh_id), by(indiv_hh_id)
drop if indiv_hh_size>1

*ID UNIQUE HHs
egen hh_id=group(primaryhousenumber primarystreetname primaryunitnumb primaryzip), missing
egen hh_size=count(hh_id), by(hh_id)
drop if hh_size>4

*ID UNIQUE HH PHONE #s
egen phone_id=group(hh_id primaryphone), missing
egen phone_size=count(phone_id), by(phone_id)


** CREATE INDICATORS TO COUNT NON-MISSINGS OF FOR HH LEVEL MEASURES
tab partycode, gen(pty_)
forvalues i=1/6{
replace pty_`i'=. if pty_`i'==0
}
rename pty_1 pty_D
rename pty_2 pty_G
rename pty_3 pty_O
rename pty_4 pty_R
rename pty_5 pty_T
rename pty_6 pty_U

recode voterscoregeneral (0 5=0) (1=1) (2=2) (3=3) (4=4) (*=.), gen(generals)

tab generals, gen(gen_)
forvalues i=1/5{
local newindex=`i'-1
rename gen_`i' gen_`newindex'
replace gen_`newindex'=. if gen_`newindex'!=1
}

*** GENERATE MEASURES OF HH CHARACTERISTICS FOR EACH VOTER
foreach u in hh_id phone_id{
foreach p in D R U G T O{
egen no_`p'_`u'=count(pty_`p'), by(`u')
}
forvalues i=0/4{
egen no_gentimes_`i'_`u'=count(gen_`i'), by(`u')
}
}

*DROP BAD/MISSING PHONE NUMBERS
drop if primaryphone==.
drop if primaryphone<2000000000
tostring primaryphone, generate(phone_string)
gen first_dig_prefix=substr(phone_string,4,1)
*drop if first digit of prefix < 2
drop if first_dig_prefix=="1" | first_dig_prefix=="0" 

*** GENERATE COUNTS OF NUMBER OF PEOPLE SHARING A PHONE NUMBER
egen shared_phone_id=group(primaryphone), missing
egen shared_phone_size=count(shared_phone_id), by(shared_phone_id)
gsort primaryphone hh_id 

* DROP IMPLAUSIBLY SHARED PHONE NUMBERS
gsort primaryphone hh_id 
count if (primaryphone[_n+1]==primaryphone & hh_id[_n+1]!=hh_id) |(primaryphone[_n-1]==primaryphone & hh_id[_n-1]!=hh_id)| (primaryphone[_n+2]==primaryphone & hh_id[_n+2]!=hh_id) |(primaryphone[_n-2]==primaryphone & hh_id[_n-2]!=hh_id) | (primaryphone[_n+3]==primaryphone & hh_id[_n+3]!=hh_id) |(primaryphone[_n-3]==primaryphone & hh_id[_n-3]!=hh_id) |(primaryphone[_n+4]==primaryphone & hh_id[_n+4]!=hh_id) |(primaryphone[_n-4]==primaryphone & hh_id[_n-4]!=hh_id) 
count if (primaryphone[_n+1]==primaryphone & lastname[_n+1]==lastname & hh_id[_n+1]!=hh_id)|(primaryphone[_n-1]==primaryphone & lastname[_n-1]==lastname & hh_id[_n-1]!=hh_id)| (primaryphone[_n+2]==primaryphone & lastname[_n+2]==lastname & hh_id[_n+2]!=hh_id)|(primaryphone[_n-2]==primaryphone & lastname[_n-2]==lastname & hh_id[_n-2]!=hh_id)| (primaryphone[_n+3]==primaryphone & lastname[_n+3]==lastname & hh_id[_n+3]!=hh_id)|(primaryphone[_n-3]==primaryphone & lastname[_n-3]==lastname & hh_id[_n-3]!=hh_id)|(primaryphone[_n+4]==primaryphone & lastname[_n+4]==lastname & hh_id[_n+4]!=hh_id)|(primaryphone[_n-4]==primaryphone & lastname[_n-4]==lastname & hh_id[_n-4]!=hh_id) 
drop if (primaryphone[_n+1]==primaryphone & hh_id[_n+1]!=hh_id) |(primaryphone[_n-1]==primaryphone & hh_id[_n-1]!=hh_id)| (primaryphone[_n+2]==primaryphone & hh_id[_n+2]!=hh_id) |(primaryphone[_n-2]==primaryphone & hh_id[_n-2]!=hh_id) | (primaryphone[_n+3]==primaryphone & hh_id[_n+3]!=hh_id) |(primaryphone[_n-3]==primaryphone & hh_id[_n-3]!=hh_id) |(primaryphone[_n+4]==primaryphone & hh_id[_n+4]!=hh_id) |(primaryphone[_n-4]==primaryphone & hh_id[_n-4]!=hh_id) 

** DROP non-Targeted individuals
drop if partycode!="U"
drop if voterscore==0|voterscore==5

*** DROP IF MORE THAN 2 PEOPLE SHARING PHONE NUMBER
drop if phone_size>2
egen target_hh_id=group(hh_id), missing

**** GENERATE STRATA (1=1-person HH, 1 phone; 2=multiperson HH, 1 phone; 3=multiperson HH, shared phone)
generate strata=3
replace strata=2 if phone_size==1 & hh_size!=1
replace strata=1 if phone_size==1 & hh_size==1
label var strata "1=1-person HH, 1 phone; 2=multiperson HH, 1 phone; 3=multiperson HH, shared phone"

*** ASSIGN TREATMENT
gsort -hh_id -firstname
gen treat_new=1
set seed 5099
gen withinHH=runiform()
set seed 555
gen treatassign_new=runiform()
gsort -hh_id -withinHH firstname
drop if hh_id==hh_id[_n-1]
forvalues i=1/3{
_pctile treatassign if strata==`i', p(25, 50, 75)
replace treat_new=0 if strata==`i' & treatassign_new<r(r1)
replace treat_new=2 if strata==`i' & treatassign_new>=r(r2)
replace treat_new=3 if strata==`i' & treatassign_new>=r(r3)
}
label var treat_new "Treatment Condition (0=control; 1=positive; 2=negative; 3=contrast)"

*** YOB
gen yob=subinstr(dob,"1/1/","",.)
destring yob, replace
drop age
gen age=2012-yob
label var age "Age in 2012"

** gender
tab gender, gen(sex_)
sum age sex_* withinHH if strata==3

*** OUTPUT CALL LIST
format primaryphone precinctnumber precinctname voterkey hhrecid clientid statevoterid %15.0g
set seed 1
gen callorder=runiform()
gsort callorder
save "data_private\sd35_draw.dta", replace


*********************************************************
*** MERGE ACTUAL CALL LISTS BACK TO CLEANED VOTER FILE***
//(using actual call lists--randomization in strata 3 initially did not have seed set properly, so randomization within household can not be replicated)
*********************************************************
clear all
insheet using "data_private\actual_call_list_sd19.csv", comma 
save "data_private\actual_19_firstround.dta", replace
clear all
insheet using "data_private\actual_call_list_sd26.csv", comma 
drop primarystreetpost 
append using "data_private\actual_19_firstround.dta"
drop primarystreetpost 
gen long extern_id=statevoterid

rename sex_1 female
rename sex_2 male

keep statevoterid voterscoregeneral age female male sex_3 treat strata sdname
sort statevoterid 
save "data_private\first_round_call_list.dta", replace


*********************************************************
*** ASSIGN TREATMENTS FOR SECOND EXPERIMENT SD 19 & 26***
*********************************************************
//note: using CSV files sent to CO Rep Party (correct within HH selection)
clear all
insheet using "data_private\actual_call_list_sd19.csv", comma 

gen treat_new=1
set seed 1020141
gen treatassign_new=runiform()
forvalues i=1/3{
_pctile treatassign_new if strata==`i', p(25, 50, 75)
replace treat_new=0 if strata==`i' & treatassign_new<r(r1)
replace treat_new=2 if strata==`i' & treatassign_new>=r(r2)
replace treat_new=3 if strata==`i' & treatassign_new>=r(r3)
}
label var treat_new "Treatment Condition (0=control; 1=positive; 2=negative; 3=contrast)"

tab treat treat_new, chi2

format primaryphone precinctnumber precinctname voterkey hhrecid clientid statevoterid %15.0g
set seed 2001
gen callorder_new=runiform()
gsort callorder_new
save "C:\Users\ddoherty\Documents\Colorado Republican Party\Files\sd19_draw_new.dta", replace

*** SD 26 ***************
clear all
insheet using "data_private\actual_call_list_sd26.csv", comma 

gen treat_new=1
set seed 1020
gen treatassign_new=runiform()
forvalues i=1/3{
_pctile treatassign_new if strata==`i', p(25, 50, 75)
replace treat_new=0 if strata==`i' & treatassign_new<r(r1)
replace treat_new=2 if strata==`i' & treatassign_new>=r(r2)
replace treat_new=3 if strata==`i' & treatassign_new>=r(r3)
}
label var treat_new "Treatment Condition (0=control; 1=positive; 2=negative; 3=contrast)"

tab treat treat_new, chi2

*** OUTPUT FILE for SURVEY FIELDING
format primaryphone precinctnumber precinctname voterkey hhrecid clientid statevoterid %15.0g
set seed 2001
gen callorder_new=runiform()
gsort callorder_new
save "data_private\sd26_draw_new.dta", replace
